function[res]=comdim(col,ndim,threshold)

  //comdim			- Finding common dimensions in multitable data (saisir format)
  // function[res]=comdim(collection,(ndim),(threshold))
  //
  //Input arguments:
  //---------------
  //collection:vector of saisir files (the numbers "nrow" of rows in each table must be equal) .
  //ndim:number of common dimensions
  //threshold (optional): if the "difference of fit"<threshold then break the
  //iterative loop
  //
  //Output arguments:
  //-----------------
  //res with fields:
  //Q : observations scores (nrow x ndim)
  //explained : 1 x ndim, percentage explanation given by each dimension
  //saliences : weight of the original tables in each
  // dimensions (ntable x ndim).
  //
  //Method published by  E.M. Qannari, I. Wakeling, P. Courcoux and H. J. H. MacFie
  //in Food quality and Preference 11 (2000) 151-154
  //
  //typical example (suppose 3 SAISIR matrices
  //"spectra1","spectra2","spectra3")
  //collection(1)=spectra1; collection(2)=spectra2; collection(3)=spectra3
  //myresult=comdim(collection);
  //map(myresult.Q,1,2);//// looking at the compromise scores
  //figure;
  //map(myresult.saliences,1,2);//// looking at the weights

  ntable=size(col); 
  for i=1:ntable;
      xs=div(col(i));
      col(i)=xs;
  end

  [nargout,nargin] = argn(0) // added by matlab2sci
  s=cell();
  
  if(nargin<3) then threshold=1E-10;  end;
  if(nargin<2) then ndim=ntable;      end;

  for(i=1:ntable)
    s(i).entries=col(i).d;
  end

  [Q.d, saliences.d,explained.d]=comdim_x(s,threshold,ndim);

  for i=1:ndim
    chaine=('D' + string(i) + '        ');
    bid(i)=part(chaine,(1:6));
  end

  for i=1:ntable
    chaine1=('t' + string(i) + '        ');
    bid1(i)=part(chaine1,(1:6));
  end
  
  Q.v=bid;
  Q.i=col(1).i;
  saliences.v=Q.v;// dimension
  saliences.i=bid1;// table
  explained.i=Q.v;
  explained.v='// explained';
  
  //Div
  Q=div(Q);
  saliences=div(saliences);
  explained=div(explained);
  
  res.scores=[];
  res.scores=Q; 
  res.weights=[];
  res.weights=saliences; 
  res.scores_tables=[];
  res.scores_tables=explained;
  
endfunction


